==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/HelmChartRepositorySpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class HelmChartRepositorySpecFluentImpl<A extends io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent<A>{
  public HelmChartRepositorySpecFluentImpl() {
  }
  public HelmChartRepositorySpecFluentImpl(io.fabric8.openshift.api.model.HelmChartRepositorySpec instance) {
    this.withConnectionConfig(instance.getConnectionConfig()); 
    this.withDescription(instance.getDescription()); 
    this.withDisabled(instance.getDisabled()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConnectionConfigBuilder connectionConfig;
  private java.lang.String description;
  private java.lang.Boolean disabled;
  private java.lang.String name;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildConnectionConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConnectionConfig getConnectionConfig() {
    return this.connectionConfig!=null?this.connectionConfig.build():null;
  }
  public io.fabric8.openshift.api.model.ConnectionConfig buildConnectionConfig() {
    return this.connectionConfig!=null?this.connectionConfig.build():null;
  }
  public A withConnectionConfig(io.fabric8.openshift.api.model.ConnectionConfig connectionConfig) {
    _visitables.get("connectionConfig").remove(this.connectionConfig);
    if (connectionConfig!=null){ this.connectionConfig= new io.fabric8.openshift.api.model.ConnectionConfigBuilder(connectionConfig); _visitables.get("connectionConfig").add(this.connectionConfig);} return (A) this;
  }
  public java.lang.Boolean hasConnectionConfig() {
    return this.connectionConfig != null;
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> withNewConnectionConfig() {
    return new io.fabric8.openshift.api.model.HelmChartRepositorySpecFluentImpl.ConnectionConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> withNewConnectionConfigLike(io.fabric8.openshift.api.model.ConnectionConfig item) {
    return new io.fabric8.openshift.api.model.HelmChartRepositorySpecFluentImpl.ConnectionConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> editConnectionConfig() {
    return withNewConnectionConfigLike(getConnectionConfig());
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> editOrNewConnectionConfig() {
    return withNewConnectionConfigLike(getConnectionConfig() != null ? getConnectionConfig(): new io.fabric8.openshift.api.model.ConnectionConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> editOrNewConnectionConfigLike(io.fabric8.openshift.api.model.ConnectionConfig item) {
    return withNewConnectionConfigLike(getConnectionConfig() != null ? getConnectionConfig(): item);
  }
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.Boolean getDisabled() {
    return this.disabled;
  }
  public A withDisabled(java.lang.Boolean disabled) {
    this.disabled=disabled; return (A) this;
  }
  public java.lang.Boolean hasDisabled() {
    return this.disabled != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HelmChartRepositorySpecFluentImpl that = (HelmChartRepositorySpecFluentImpl) o;
    if (connectionConfig != null ? !connectionConfig.equals(that.connectionConfig) :that.connectionConfig != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(connectionConfig,  description,  disabled,  name,  additionalProperties,  super.hashCode());
  }
  public class ConnectionConfigNestedImpl<N> extends io.fabric8.openshift.api.model.ConnectionConfigFluentImpl<io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<N>> implements io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConnectionConfigNestedImpl(io.fabric8.openshift.api.model.ConnectionConfig item) {
      this.builder = new io.fabric8.openshift.api.model.ConnectionConfigBuilder(this, item);
    }
    ConnectionConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConnectionConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.ConnectionConfigBuilder builder;
    public N and() {
      return (N) HelmChartRepositorySpecFluentImpl.this.withConnectionConfig(builder.build());
    }
    public N endConnectionConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/HelmChartRepositorySpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class HelmChartRepositorySpecFluentImpl<A extends io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent<A>{
  public HelmChartRepositorySpecFluentImpl() {
  }
  public HelmChartRepositorySpecFluentImpl(io.fabric8.openshift.api.model.HelmChartRepositorySpec instance) {
    this.withConnectionConfig(instance.getConnectionConfig()); 
    this.withDescription(instance.getDescription()); 
    this.withDisabled(instance.getDisabled()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConnectionConfigBuilder connectionConfig;
  private java.lang.String description;
  private java.lang.Boolean disabled;
  private java.lang.String name;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildConnectionConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConnectionConfig getConnectionConfig() {
    return this.connectionConfig!=null?this.connectionConfig.build():null;
  }
  public io.fabric8.openshift.api.model.ConnectionConfig buildConnectionConfig() {
    return this.connectionConfig!=null?this.connectionConfig.build():null;
  }
  public A withConnectionConfig(io.fabric8.openshift.api.model.ConnectionConfig connectionConfig) {
    _visitables.get("connectionConfig").remove(this.connectionConfig);
    if (connectionConfig!=null){ this.connectionConfig= new io.fabric8.openshift.api.model.ConnectionConfigBuilder(connectionConfig); _visitables.get("connectionConfig").add(this.connectionConfig);} return (A) this;
  }
  public java.lang.Boolean hasConnectionConfig() {
    return this.connectionConfig != null;
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> withNewConnectionConfig() {
    return new io.fabric8.openshift.api.model.HelmChartRepositorySpecFluentImpl.ConnectionConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> withNewConnectionConfigLike(io.fabric8.openshift.api.model.ConnectionConfig item) {
    return new io.fabric8.openshift.api.model.HelmChartRepositorySpecFluentImpl.ConnectionConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> editConnectionConfig() {
    return withNewConnectionConfigLike(getConnectionConfig());
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> editOrNewConnectionConfig() {
    return withNewConnectionConfigLike(getConnectionConfig() != null ? getConnectionConfig(): new io.fabric8.openshift.api.model.ConnectionConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<A> editOrNewConnectionConfigLike(io.fabric8.openshift.api.model.ConnectionConfig item) {
    return withNewConnectionConfigLike(getConnectionConfig() != null ? getConnectionConfig(): item);
  }
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.Boolean getDisabled() {
    return this.disabled;
  }
  public A withDisabled(java.lang.Boolean disabled) {
    this.disabled=disabled; return (A) this;
  }
  public java.lang.Boolean hasDisabled() {
    return this.disabled != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HelmChartRepositorySpecFluentImpl that = (HelmChartRepositorySpecFluentImpl) o;
    if (connectionConfig != null ? !connectionConfig.equals(that.connectionConfig) :that.connectionConfig != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(connectionConfig,  description,  disabled,  name,  additionalProperties,  super.hashCode());
  }
  public class ConnectionConfigNestedImpl<N> extends io.fabric8.openshift.api.model.ConnectionConfigFluentImpl<io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<N>> implements io.fabric8.openshift.api.model.HelmChartRepositorySpecFluent.ConnectionConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConnectionConfigNestedImpl(io.fabric8.openshift.api.model.ConnectionConfig item) {
      this.builder = new io.fabric8.openshift.api.model.ConnectionConfigBuilder(this, item);
    }
    ConnectionConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConnectionConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.ConnectionConfigBuilder builder;
    public N and() {
      return (N) HelmChartRepositorySpecFluentImpl.this.withConnectionConfig(builder.build());
    }
    public N endConnectionConfig() {
      return and();
    }
    
  }
  
}
